@@ -57,6 +57,7 @@ namespace Oxygen
         connect( m_ui.buttonSize, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( m_ui.drawBorderOnMaximizedWindows, SIGNAL(clicked()), SLOT(updateChanged()) );
         connect( m_ui.drawSizeGrip, SIGNAL(clicked()), SLOT(updateChanged()) );
+        connect( m_ui.useWindowColors, SIGNAL(clicked()), SLOT(updateChanged()) );
         connect( m_ui.animationConfigWidget, SIGNAL(changed(bool)), SLOT(updateChanged()) );
 
         // track exception changes
@@ -81,6 +82,7 @@ namespace Oxygen
         m_ui.buttonSize->setCurrentIndex( m_internalSettings->buttonSize() );
         m_ui.drawBorderOnMaximizedWindows->setChecked( m_internalSettings->drawBorderOnMaximizedWindows() );
         m_ui.drawSizeGrip->setChecked( m_internalSettings->drawSizeGrip() );
+        m_ui.useWindowColors->setChecked( m_internalSettings->useWindowColors() );
 
         // load animations
         m_ui.animationConfigWidget->setInternalSettings( m_internalSettings );
@@ -112,6 +114,7 @@ namespace Oxygen
         m_internalSettings->setButtonSize( m_ui.buttonSize->currentIndex() );
         m_internalSettings->setDrawBorderOnMaximizedWindows( m_ui.drawBorderOnMaximizedWindows->isChecked() );
         m_internalSettings->setDrawSizeGrip( m_ui.drawSizeGrip->isChecked() );
+        m_internalSettings->setUseWindowColors( m_ui.useWindowColors->isChecked() );
 
         // save animations
         m_ui.animationConfigWidget->setInternalSettings( m_internalSettings );
@@ -160,6 +163,7 @@ namespace Oxygen
         m_ui.buttonSize->setCurrentIndex( m_internalSettings->buttonSize() );
         m_ui.drawBorderOnMaximizedWindows->setChecked( m_internalSettings->drawBorderOnMaximizedWindows() );
         m_ui.drawSizeGrip->setChecked( m_internalSettings->drawSizeGrip() );
+        m_ui.useWindowColors->setChecked( m_internalSettings->useWindowColors() );
 
         // load shadows
         m_ui.activeShadowConfiguration->setDefaults();
@@ -187,6 +191,7 @@ namespace Oxygen
         else if( m_ui.buttonSize->currentIndex() != m_internalSettings->buttonSize() ) modified = true;
         else if( m_ui.drawBorderOnMaximizedWindows->isChecked() !=  m_internalSettings->drawBorderOnMaximizedWindows() ) modified = true;
         else if( m_ui.drawSizeGrip->isChecked() !=  m_internalSettings->drawSizeGrip() ) modified = true;
+        else if( m_ui.useWindowColors->isChecked() !=  m_internalSettings->useWindowColors() ) modified = true;
 
         // animations
         else if( m_ui.animationConfigWidget->isChanged() ) modified = true;
